#ifndef COLLISIONS_H
#define COLLISIONS_H

#include <vector>
#include "vec3f.h"

struct Collisions
{
   // Stores collision geometry of scene. In this case, it's just the coefficient a in y=a(x^2+z^2) which
   // defines a heightfield.
   float parabola_coeff;

   // and collision parameters. In this case, the collisions are purely inelastic, so friction is the
   // only interesting parameter.
   float friction_coeff;

   explicit Collisions(float parabola_coeff_=1.5, float friction_coeff_=0.2)
      : parabola_coeff(parabola_coeff_), friction_coeff(friction_coeff_)
   {}

   // call this from Mud::advance_time_step to resolve all the particle collisions
   void resolve_inelastic_particle_collisions(float collision_dt, const std::vector<Vec3f> &oldx,
	                                      std::vector<Vec3f > &x, std::vector<Vec3f > &v);

   private:
   void resolve_inelastic_collision(float collision_dt, const Vec3f &oldx, Vec3f &x, Vec3f &v);
};

#endif
